@@ -666,7 +666,13 @@ def res_archive_load(ctx, **kwargs):
 @click.option(
     "-r",
     "--remote",
-    help="The name of the remote to also install the package to. Can be omitted if there is only one remote configured",
+    help="The name of the remote to also install the package to. Can be omitted if there is only one remote configured.",
+    required=False,
+)
+@click.option(
+    "-c",
+    "--channel",
+    help="Specify the conda channel from which to install the packages.",
     required=False,
 )
 @click.option(
@@ -675,6 +681,14 @@ def res_archive_load(ctx, **kwargs):
     help="Also install the package to all configured remotes",
     required=False,
 )
+@click.option(
+    "-M",
+    "--mamba",
+    is_flag=True,
+    default=False,
+    help="Try to use mamba instead of conda for dependency resolution.",
+    required=False,
+)
 @click.pass_context
 def res_install(ctx, packages, **kwargs):
     """
@@ -682,23 +696,30 @@ def res_install(ctx, packages, **kwargs):
 
     """
     all_remotes = kwargs.get("all_remotes")
+    channel = kwargs.get("channel")
+    mamba = kwargs.get("mamba")
+
     if all_remotes:
-        install_conda_packages(packages)
+        install_conda_packages(packages, channel=channel, mamba=mamba)
         db = read_remote_db()
         remote_ids = list_remote_ids(db)
         for remote_id in remote_ids:
             remote_settings = get_remote(db, remote_id)
-            install_conda_packages(packages, remote_settings)
+            install_conda_packages(
+                packages, target=remote_settings, channel=channel, mamba=mamba
+            )
     else:
         try:
             remote_settings = get_remote(read_remote_db(), kwargs.get("remote"))
-            install_conda_packages(packages)
-            install_conda_packages(packages, remote_settings)
+            install_conda_packages(packages, channel=channel, mamba=mamba)
+            install_conda_packages(
+                packages, target=remote_settings, channel=channel, mamba=mamba
+            )
         except NoRemotesError as ex:
             clog.info(
                 "No remotes were specified, will only install the package locally"
             )
-            install_conda_packages(packages)
+            install_conda_packages(packages, channel=channel, mamba=mamba)
 
     clog.info(f"Successfully installed packages {packages}")
 
